==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/transform/GnomeTransformerFactory__24AssociatedStylesheetHandler.h <==
// class gnu.xml.libxmlj.transform.GnomeTransformerFactory$AssociatedStylesheetHandler

// class file dependencies
// @dep_class 6ea9839e20f1a01b gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e131d6480dcd928c org_xml_sax_helpers_DefaultHandler

// header file dependencies
// @dep_header org_xml_sax_helpers_DefaultHandler

#include "org/xml/sax/helpers/DefaultHandler.h"

#ifndef _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_
#define _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object;

typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable;
typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method$_init$155cb5123a9ed41e(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object *);

// Virtual methods
extern void _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method$processingInstruction$ec2152776ab9b938(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method_info$processingInstruction$ec2152776ab9b938;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods {
	void	(*processingInstruction$ec2152776ab9b938)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_DefaultHandler$vmethods	org_xml_sax_helpers_DefaultHandler;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
};

// Vtype
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs {
	struct _jc_java_lang_String$object	*media;
	struct _jc_java_lang_String$object	*title;
	struct _jc_java_lang_String$object	*href;
	struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs {
    _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
    _jc_org_xml_sax_helpers_DefaultHandler$sub_refs	org_xml_sax_helpers_DefaultHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_DefaultHandler$sub_nonrefs	org_xml_sax_helpers_DefaultHandler;
    _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object {
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype	*vtype;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$class_object;

#endif	/* _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/transform/GnomeTransformerFactory__24AssociatedStylesheetHandler.h <==
// class gnu.xml.libxmlj.transform.GnomeTransformerFactory$AssociatedStylesheetHandler

// class file dependencies
// @dep_class 6ea9839e20f1a01b gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e131d6480dcd928c org_xml_sax_helpers_DefaultHandler

// header file dependencies
// @dep_header org_xml_sax_helpers_DefaultHandler

#include "org/xml/sax/helpers/DefaultHandler.h"

#ifndef _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_
#define _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object;

typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable;
typedef const struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method$_init$155cb5123a9ed41e(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method$processingInstruction$ec2152776ab9b938(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$method_info$processingInstruction$ec2152776ab9b938;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods {
	void	(*processingInstruction$ec2152776ab9b938)(_jc_env *, struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_DefaultHandler$vmethods	org_xml_sax_helpers_DefaultHandler;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vmethods	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
};

// Vtype
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs {
	struct _jc_java_lang_String$object	*media;
	struct _jc_java_lang_String$object	*title;
	struct _jc_java_lang_String$object	*href;
	struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs {
    _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_refs	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
    _jc_org_xml_sax_helpers_DefaultHandler$sub_refs	org_xml_sax_helpers_DefaultHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_DefaultHandler$sub_nonrefs	org_xml_sax_helpers_DefaultHandler;
    _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$sub_nonrefs	gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$object {
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype	*vtype;
	_jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$vtype _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler$class_object;

#endif	/* _JC_gnu_xml_libxmlj_transform_GnomeTransformerFactory__24AssociatedStylesheetHandler_H_ */
